@@ -1,12 +1,12 @@
 IDFcurve2 <- function (rain, tc, stvalue1 = 1, stvalue2 = 1, t, Tr = 200, MP = F, Trplot = F)
 { options(warn = -1)
   rain <- annualmax(rain)
-    rain <- as.matrix(rain)
-    nr <- nrow(rain)
+  rain <- as.matrix(rain)
+  nr <- nrow(rain)
     vb1 <- vb(nr - 1)
     Ev3 <- rain
     for (k in 1:ncol(rain)) Ev3[,k]=(Ev3[,k])/(t[k])
-    ris <- nlm(f4,c(vb1,1),x3=rain,t,iterlim=1000)
+    ris <- nlm(f4,c(vb1, stvalue1),x3=rain,t,iterlim=1000)
  if (MP)
     ris <- nlm(f5, c(ris$estimate, stvalue2),x3=rain,t,iterlim=1000)
     mu <- mean(ris$estimate[1:nr]) - 0.45006 * sd(ris$estimate[1:nr])
